@@ -44,17 +44,13 @@ __all__ = (
     "MetricAlarmsCollection",
 )
 
-_ServiceResourceAlarmsCollectionType = TypeVar(
-    "_ServiceResourceAlarmsCollectionType", bound="ServiceResourceAlarmsCollection"
-)
-
 
 class ServiceResourceAlarmsCollection(ResourceCollection):
     """
-    [ServiceResource.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
+    [ServiceResource.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
     """
 
-    def all(self) -> _ServiceResourceAlarmsCollectionType:
+    def all(self) -> "ServiceResourceAlarmsCollection":
         pass
 
     def filter(
@@ -68,7 +64,7 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
         ActionPrefix: str = None,
         MaxRecords: int = None,
         NextToken: str = None,
-    ) -> _ServiceResourceAlarmsCollectionType:
+    ) -> "ServiceResourceAlarmsCollection":
         pass
 
     def delete(self) -> None:
@@ -80,10 +76,10 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
     def enable_actions(self) -> None:
         pass
 
-    def limit(self, count: int) -> _ServiceResourceAlarmsCollectionType:
+    def limit(self, count: int) -> "ServiceResourceAlarmsCollection":
         pass
 
-    def page_size(self, count: int) -> _ServiceResourceAlarmsCollectionType:
+    def page_size(self, count: int) -> "ServiceResourceAlarmsCollection":
         pass
 
     def pages(self) -> Iterator["Alarm"]:
@@ -93,17 +89,12 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
         pass
 
 
-_ServiceResourceMetricsCollectionType = TypeVar(
-    "_ServiceResourceMetricsCollectionType", bound="ServiceResourceMetricsCollection"
-)
-
-
 class ServiceResourceMetricsCollection(ResourceCollection):
     """
-    [ServiceResource.metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
+    [ServiceResource.metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
     """
 
-    def all(self) -> _ServiceResourceMetricsCollectionType:
+    def all(self) -> "ServiceResourceMetricsCollection":
         pass
 
     def filter(
@@ -112,13 +103,13 @@ class ServiceResourceMetricsCollection(ResourceCollection):
         MetricName: str = None,
         Dimensions: List[DimensionFilterTypeDef] = None,
         NextToken: str = None,
-    ) -> _ServiceResourceMetricsCollectionType:
+    ) -> "ServiceResourceMetricsCollection":
         pass
 
-    def limit(self, count: int) -> _ServiceResourceMetricsCollectionType:
+    def limit(self, count: int) -> "ServiceResourceMetricsCollection":
         pass
 
-    def page_size(self, count: int) -> _ServiceResourceMetricsCollectionType:
+    def page_size(self, count: int) -> "ServiceResourceMetricsCollection":
         pass
 
     def pages(self) -> Iterator["Metric"]:
@@ -128,15 +119,12 @@ class ServiceResourceMetricsCollection(ResourceCollection):
         pass
 
 
-_MetricAlarmsCollectionType = TypeVar("_MetricAlarmsCollectionType", bound="MetricAlarmsCollection")
-
-
 class MetricAlarmsCollection(ResourceCollection):
     """
-    [Metric.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
+    [Metric.alarms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
     """
 
-    def all(self) -> _MetricAlarmsCollectionType:
+    def all(self) -> "MetricAlarmsCollection":
         pass
 
     def filter(
@@ -174,7 +162,7 @@ class MetricAlarmsCollection(ResourceCollection):
             "Count/Second",
             "None",
         ] = None,
-    ) -> _MetricAlarmsCollectionType:
+    ) -> "MetricAlarmsCollection":
         pass
 
     def delete(self) -> None:
@@ -186,10 +174,10 @@ class MetricAlarmsCollection(ResourceCollection):
     def enable_actions(self) -> None:
         pass
 
-    def limit(self, count: int) -> _MetricAlarmsCollectionType:
+    def limit(self, count: int) -> "MetricAlarmsCollection":
         pass
 
-    def page_size(self, count: int) -> _MetricAlarmsCollectionType:
+    def page_size(self, count: int) -> "MetricAlarmsCollection":
         pass
 
     def pages(self) -> Iterator["Alarm"]:
@@ -199,12 +187,9 @@ class MetricAlarmsCollection(ResourceCollection):
         pass
 
 
-_AlarmType = TypeVar("_AlarmType", bound="Alarm")
-
-
 class Alarm(Boto3ServiceResource):
     """
-    [Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+    [Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
     """
 
     alarm_name: str
@@ -238,7 +223,7 @@ class Alarm(Boto3ServiceResource):
 
     def delete(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
+        [Alarm.delete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
         """
 
     def describe_history(
@@ -252,32 +237,32 @@ class Alarm(Boto3ServiceResource):
         ScanBy: Literal["TimestampDescending", "TimestampAscending"] = None,
     ) -> DescribeAlarmHistoryOutputTypeDef:
         """
-        [Alarm.describe_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
+        [Alarm.describe_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
         """
 
     def disable_actions(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.disable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
+        [Alarm.disable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
         """
 
     def enable_actions(self, AlarmNames: List[str]) -> None:
         """
-        [Alarm.enable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
+        [Alarm.enable_actions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Alarm.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
+        [Alarm.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
         """
 
     def load(self) -> None:
         """
-        [Alarm.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
+        [Alarm.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
         """
 
     def reload(self) -> None:
         """
-        [Alarm.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
+        [Alarm.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
         """
 
     def set_state(
@@ -287,19 +272,16 @@ class Alarm(Boto3ServiceResource):
         StateReasonData: str = None,
     ) -> None:
         """
-        [Alarm.set_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
+        [Alarm.set_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
         """
 
 
 _Alarm = Alarm
 
 
-_MetricType = TypeVar("_MetricType", bound="Metric")
-
-
 class Metric(Boto3ServiceResource):
     """
-    [Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+    [Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
     """
 
     metric_name: str
@@ -310,7 +292,7 @@ class Metric(Boto3ServiceResource):
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Metric.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
+        [Metric.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
         """
 
     def get_statistics(
@@ -352,12 +334,12 @@ class Metric(Boto3ServiceResource):
         ] = None,
     ) -> GetMetricStatisticsOutputTypeDef:
         """
-        [Metric.get_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
+        [Metric.get_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
         """
 
     def load(self) -> None:
         """
-        [Metric.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.load)
+        [Metric.load documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Metric.load)
         """
 
     def put_alarm(
@@ -420,17 +402,17 @@ class Metric(Boto3ServiceResource):
         ThresholdMetricId: str = None,
     ) -> _Alarm:
         """
-        [Metric.put_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
+        [Metric.put_alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
         """
 
     def put_data(self, MetricData: List[MetricDatumTypeDef]) -> None:
         """
-        [Metric.put_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
+        [Metric.put_data documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
         """
 
     def reload(self) -> None:
         """
-        [Metric.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
+        [Metric.reload documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
         """
 
 
@@ -439,7 +421,7 @@ _Metric = Metric
 
 class CloudWatchServiceResource(Boto3ServiceResource):
     """
-    [CloudWatch.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
+    [CloudWatch.ServiceResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
     """
 
     alarms: ServiceResourceAlarmsCollection
@@ -447,15 +429,15 @@ class CloudWatchServiceResource(Boto3ServiceResource):
 
     def Alarm(self, name: str) -> _Alarm:
         """
-        [ServiceResource.Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+        [ServiceResource.Alarm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
         """
 
     def Metric(self, namespace: str, name: str) -> _Metric:
         """
-        [ServiceResource.Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+        [ServiceResource.Metric documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
+        [ServiceResource.get_available_subresources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.18/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
         """
